<?php

  /**
   * Created by IntelliJ IDEA.
   * User: timlindsay
   * Date: 5/09/13
   * Time: 8:55 PM
   * Class projectsList
   *
   * Responsible for doing stuff with your projects list
   *
   * The file format should be ...
   *
   * PROJKEY The name of the project
   *
   */
  class projectList {

    /** A keyed array or project IDs and their descriptions */
    private $projects;

    /**
     * Load the requested data file
     *
     * @param $file_path
     */
    public function __construct($file_path) {
      if (!file_exists($file_path)) {
        $this->projects = array();
        return NULL;
      }
      $existing_file = file_get_contents($file_path);
      $lines         = explode("\n", $existing_file);
      foreach ($lines as $project) {
        //Remove additional whitespace
        $project = trim(preg_replace('/\s+/', ' ', $project));
        $line    = explode(" ", $project);
        //Key is the first column
        $key = array_shift($line);
        //Rest of the line is the name of the project
        $name                = implode(' ', $line);
        $this->projects[$key] = $name;
      }

    }

    /**
     * Find the requested project by key.
     *
     * @param $id
     *
     * @return string|null Name of projects
     */
    public function find($id) {
      if (array_key_exists($id, $this->projects)) {
        return $this->projects[$id];
      }
      return NULL;
    }


    /**
     * Return a HTML formatted options list
     */
    public function getOptionsList($preselect) {
      if (!$this->find($preselect)) {
        $op = '<option selected="selected">Select Project</option>';
      }
      else {
        $op = '';
      }

      if (count($this->projects) > 0) {
        foreach ($this->projects as $key => $name) {
          $op .= "<option ";
          if ($preselect == $key) {
            $op .= ' selected="selected" ';
          }
          $op .= " value=\"${key} - ${name}\">${key} - ${name}</option>";
        }
      }
      return $op;
    }


  }
